@@ -12,7 +12,6 @@
 package Lemonldap::NG::Manager::Sessions;
 
 use strict;
-use File::Basename;
 use Lemonldap::NG::Handler::CGI qw(:globalStorage :locationRules);
 use Lemonldap::NG::Common::Apache::Session;   #inherits
 use Lemonldap::NG::Common::Conf;              #link protected conf Configuration
@@ -25,7 +24,7 @@ use utf8;
 our $whatToTrace;
 *whatToTrace = \$Lemonldap::NG::Handler::_CGI::whatToTrace;
 
-our $VERSION = '1.1.0';
+our $VERSION = '1.2.1';
 
 our @ISA = qw(
   Lemonldap::NG::Handler::CGI
@@ -75,17 +74,12 @@ sub new {
     %{ $self->{globalStorageOptions} } = %$globalStorageOptions;
     $self->{globalStorageOptions}->{backend} = $globalStorage;
 
-    # Check if we use X-FORWARDED-FOR header for IP
-    $self->{ipField} =
-      $self->{useXForwardedForIP} ? "xForwardedForAddr" : "ipAddr";
+    # IP field
+    $self->{ipField} = "ipAddr";
 
     # Multi values separator
     $self->{multiValuesSeparator} ||= '; ';
 
-    # Absolute path to the htdocs directory where is manager script.
-    my ( $mname, $mpath, $msuffix ) = fileparse( $ENV{SCRIPT_FILENAME} );
-    $self->{managerHtdocsPath} = $mpath;
-
     # Now we're ready to display sessions. Choose display type
     foreach my $k ( $self->param() ) {
 
@@ -487,7 +481,7 @@ sub session {
     # Map attributes to categories
     my $categories = {
         'dateTitle'       => [qw(_utime startTime updateTime _lastAuthnUTime)],
-        'connectionTitle' => [qw(ipAddr xForwardedForAddr _timezone _url)],
+        'connectionTitle' => [qw(ipAddr _timezone _url)],
         'authenticationTitle' =>
           [qw(_session_id _user _password authenticationLevel)],
         'modulesTitle' => [qw(_auth _userDB _passwordDB _issuerDB _authChoice)],
@@ -587,6 +581,45 @@ sub session {
         $res .= '</div>';
     }
 
+    # Login history
+    if ( defined $session{loginHistory} ) {
+        $res .= '<div class="ui-corner-all ui-widget-content category">';
+        $res .= '<h2 class="ui-corner-all ui-widget-header">'
+          . ucfirst $self->translate('loginHistory') . '</h2>';
+        $res .= '<ul>';
+
+        # Get all login records
+        my $loginRecords = {};
+
+        if ( defined $session{loginHistory}->{successLogin} ) {
+            foreach ( @{ $session{loginHistory}->{successLogin} } ) {
+                $loginRecords->{ $_->{_utime} } =
+                  "Success (IP " . $_->{ipAddr} . ")";
+            }
+        }
+
+        if ( defined $session{loginHistory}->{failedLogin} ) {
+            foreach ( @{ $session{loginHistory}->{failedLogin} } ) {
+                $loginRecords->{ $_->{_utime} } =
+                  $_->{error} . " (IP " . $_->{ipAddr} . ")";
+            }
+        }
+
+        # Display records sorted by date
+        foreach my $utime ( sort keys %{$loginRecords} ) {
+
+            $res .=
+                "<li><strong>"
+              . localtime($utime)
+              . "</strong>: "
+              . $loginRecords->{$utime} . "</li>";
+        }
+
+        delete $session{loginHistory};
+        $res .= '</ul>';
+        $res .= '</div>';
+    }
+
     # Other attributes
     $res .= '<div class="ui-corner-all ui-widget-content category">';
     $res .= '<h2 class="ui-corner-all ui-widget-header">'
@@ -825,6 +858,8 @@ sub _stToStr {
 1;
 __END__
 
+=encoding utf8
+
 =head1 NAME
 
 Lemonldap::NG::Manager::Sessions - Perl extension to manage Lemonldap::NG
@@ -839,13 +874,13 @@ sessions
   our $cgi ||= Lemonldap::NG::Manager::Sessions->new({
         localStorage        => "Cache::FileCache",
         localStorageOptions => {
-            'namespace'          => 'MyNamespace',
+            'namespace'          => 'lemonldap-ng',
             'default_expires_in' => 600,
             'directory_umask'    => '007',
             'cache_root'         => '/tmp',
             'cache_depth'        => 5,
         },
-        configStorage => $Lemonldap::NG::Conf::configStorage,
+        configStorage => $Lemonldap::NG::Common::configStorage,
         configStorage=>{
           type=>'File',
           dirName=>"/tmp/",
@@ -853,8 +888,6 @@ sessions
         https         => 1,
         jqueryUri     => '/js/jquery/jquery.js',
         imagePath     => '/js/jquery.simple.tree/',
-        # Force the use of X-FORWARDED-FOR for IP
-        useXForwardedForIP => 1,
         # Optionnal
         protection    => 'rule: $uid eq "admin"',
         # Or to use rules from manager
@@ -878,14 +911,53 @@ L<Lemonldap::NG::Handler::CGI>, L<Lemonldap::NG::Manager>
 
 =head1 AUTHOR
 
-Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+=over
+
+=item Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
+
+=head1 BUG REPORT
+
+Use OW2 system to report bug or ask for features:
+L<http://jira.ow2.org>
+
+=head1 DOWNLOAD
+
+Lemonldap::NG is available at
+L<http://forge.objectweb.org/project/showfiles.php?group_id=274>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2008, 2010 by Xavier Guimard
+=over
+
+=item Copyright (C) 2008, 2009, 2010, 2013 by Xavier Guimard, E<lt>x.guimard@free.frE<gt>
+
+=item Copyright (C) 2012 by Franois-Xavier Deltombe, E<lt>fxdeltombe@gmail.com.E<gt>
+
+=item Copyright (C) 2009, 2010, 2011, 2012 by Clement Oudot, E<lt>clem.oudot@gmail.comE<gt>
+
+=item Copyright (C) 2010, 2011 by Thomas Chemineau, E<lt>thomas.chemineau@gmail.comE<gt>
+
+=back
 
 This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself, either Perl version 5.10.0 or,
-at your option, any later version of Perl 5 you may have available.
+it under the terms of the GNU General Public License as published by
+the Free Software Foundation; either version 2, or (at your option)
+any later version.
+
+This program is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+GNU General Public License for more details.
+
+You should have received a copy of the GNU General Public License
+along with this program.  If not, see L<http://www.gnu.org/licenses/>.
 
 =cut
